
#include "test-class.h"

typedef struct _faa_1 {
	
	char a;
	int b;
} faa_1_t;
 
 
MyClass *klass;

 
//klass->

int func_test1() {

	YourClass klass();

	


	return 0;
}



YourClass *hey;


int main() {

	faa_1_t faa;
	
	//faa
	

//	MyClass klass();
	YourClass *klass, *yklass;
		
	MyClass *my_class;
	
//	my_class->
	
	First::Second::Second_1_class *sec_class;
	sec_class->func_second_1_class_foo ();
	
	Third::Fourth::Fourth_1_class *fourth_class = new Third::Fourth::Fourth_1_class;
	
	fourth_class->func_fourth_1_class_foo ();
//	yklass->
	
	
	return 0;

}
